@@ -18,16 +18,18 @@ from .DataFormat import getDataType
 
 
 class MsbClient(websocket.WebSocketApp):
-    """Definition of the msb client to handle the creation of the self-description 
-    and communication with the msb websocket interface.
+    """Definition of the msb client to handle the creation of the self-description
+     and communication with the msb websocket interface.
     """
+
     def __init__(
-        self, 
-        service_type=None, 
-        uuid=None, 
-        name=None, 
-        description=None, 
-        token=None
+        self,
+        service_type=None,
+        uuid=None,
+        name=None,
+        description=None,
+        token=None,
+        applicationPropertiesCustomPath=None
     ):
         """Initializes a new msb client.
 
@@ -46,6 +48,7 @@ class MsbClient(websocket.WebSocketApp):
 
         self.msb_url = ""
         self.msb_url_with_wspath = ""
+        self.applicationPropertiesCustomPath = applicationPropertiesCustomPath
 
         # debugging
         self.debug = False
@@ -185,7 +188,10 @@ class MsbClient(websocket.WebSocketApp):
                 ].startswith("//"):
                     jmsg["functionId"] = jmsg["functionId"][1:]
             if jmsg["functionId"] in self.functions:
-                jmsg["functionParameters"]["correlationId"] = jmsg["correlationId"]
+                if "correlationId" in jmsg:
+                    jmsg["functionParameters"]["correlationId"] = jmsg["correlationId"]
+                else:
+                    logging.debug("correlationid could not be found. Does the websocket interface version support it?")
                 self.functions[jmsg["functionId"]].implementation(
                     jmsg["functionParameters"]
                 )
@@ -248,10 +254,10 @@ class MsbClient(websocket.WebSocketApp):
             trace (bool): Used to either enable (true) or disable (false) websocket trace
         """
         websocket.enableTrace(trace)
-    
+
     def enableDataFormatValidation(self, dataFormatValidation=True):
         """Enables or disables data format and message format validation.
-        
+
         (Mainly for development, can be disabled in production to improve performance)
 
         Args:
@@ -395,7 +401,7 @@ class MsbClient(websocket.WebSocketApp):
                                 "cert_reqs": ssl.CERT_NONE,
                                 "check_hostname": False,
                             },
-                            suppress_origin = True
+                            suppress_origin=True
                         )
                     else:
                         ws.run_forever(
@@ -403,7 +409,7 @@ class MsbClient(websocket.WebSocketApp):
                                 "cert_reqs": ssl.CERT_NONE,
                                 "check_hostname": False,
                             },
-                            suppress_origin = True
+                            suppress_origin=True
                         )
                 else:
                     if self.keepAlive:
@@ -493,7 +499,7 @@ class MsbClient(websocket.WebSocketApp):
                         "$ref"
                     ] = event.dataFormat["dataObject"]["$ref"]
                     del event.dataFormat["dataObject"]["$ref"]
-             # if not an array of complex objects, change dataformat to type object
+            # if not an array of complex objects, change dataformat to type object
             elif not event.isArray:
                 if "$ref" in event.dataFormat["dataObject"]:
                     event.dataFormat["dataObject"]["type"] = "object"
@@ -824,23 +830,28 @@ class MsbClient(websocket.WebSocketApp):
         return self_description
 
     def readConfig(self):
-        """Helper function to parse main configuration param by param name from the application.properties file"""  
+        """Helper function to parse main configuration param by param name from the application.properties file"""
         logging.info("Reading configuration from application.properties file")
-        config = open("application.properties", "r")
-        for line in config:
-            configparam = line.split("=")
-            if configparam[0] == "msb.type":
-                self.service_type = configparam[1].rstrip()
-            elif configparam[0] == "msb.name":
-                self.name = configparam[1].rstrip()
-            elif configparam[0] == "msb.uuid":
-                self.uuid = configparam[1].rstrip()
-            elif configparam[0] == "msb.token":
-                self.token = configparam[1].rstrip()
-            elif configparam[0] == "msb.url":
-                self.msb_url = configparam[1].rstrip()
-            elif configparam[0] == "msb.description":
-                self.description = configparam[1].rstrip()
+        config = None
+        if self.applicationPropertiesCustomPath is None:
+            config = open("application.properties", "r")
+        else:
+            config = open(str(self.applicationPropertiesCustomPath), "r")
+        if config is not None:
+            for line in config:
+                configparam = line.split("=")
+                if configparam[0] == "msb.type":
+                    self.service_type = configparam[1].rstrip()
+                elif configparam[0] == "msb.name":
+                    self.name = configparam[1].rstrip()
+                elif configparam[0] == "msb.uuid":
+                    self.uuid = configparam[1].rstrip()
+                elif configparam[0] == "msb.token":
+                    self.token = configparam[1].rstrip()
+                elif configparam[0] == "msb.url":
+                    self.msb_url = configparam[1].rstrip()
+                elif configparam[0] == "msb.description":
+                    self.description = configparam[1].rstrip()
 
 
 def vadilateEventDataFormat(df):
